Rename AnonTypedRegion to TypedViewRegion.

git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@65764 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Analysis/CFRefCount.cpp b/lib/Analysis/CFRefCount.cpp
index d42a936..5966997 100644
--- a/lib/Analysis/CFRefCount.cpp
+++ b/lib/Analysis/CFRefCount.cpp
@@ -1643,9 +1643,9 @@
         
         const TypedRegion* R = dyn_cast<TypedRegion>(MR->getRegion());
         
         // Blast through AnonTypedRegions to get the original region type.
         while (R) {
-          const AnonTypedRegion* ATR = dyn_cast<AnonTypedRegion>(R);
+          const TypedViewRegion* ATR = dyn_cast<TypedViewRegion>(R);
           if (!ATR) break;
           R = dyn_cast<TypedRegion>(ATR->getSuperRegion());
         }
@@ -1643,9 +1643,9 @@
         const TypedRegion* R = dyn_cast<TypedRegion>(MR->getRegion());
         
-        // Blast through AnonTypedRegions to get the original region type.
+        // Blast through TypedViewRegions to get the original region type.
         while (R) {